#!/bin/bash
#############################################################
##	change_hostname.sh
##
##-----------------------------------------------------------
##	changes the hostname
##
##-----------------------------------------------------------
##
##	Copyright (c) 2014 Dell Computer Corporation
##
#############################################################
function setHostName {

	# changing the static hostname for centos 7 
	hostnamectl set-hostname ${1}
	
	# edit the network file that holds the hostname
	local -r networkFile="/etc/sysconfig/network"  # centos6 location
	
	if (( `grep -c "HOSTNAME" "${networkFile}"` > 0 )); then
		echo "editing the hostname in the networking file"
		sed -i "s/.*HOSTNAME.*/HOSTNAME=${1}/" ${networkFile}
	else
		echo "adding the hostname to the networking file"
		echo "HOSTNAME=${1}" >> ${networkFile}
	fi
	
	# set the hostname variable so we don't have to reboot the box
	#echo "setting the hostname on the box"
    #centos 6 way
    hostname "${1}"
}

function setDNS {
    if [ -e /etc/dhclient.conf ]; then 
        rm -f /etc/dhclient.conf
        echo "request subnet-mask, broadcast-address, time-offset, routers, domain-name, domain-name-servers, host-name, nis-domain, nis-servers, interface-mtu;" > /etc/dhclient.conf
        echo "send fqdn.fqdn "${1}";" >> /etc/dhclient.conf
        echo "send fqdn.encoded on;" >> /etc/dhclient.conf
        echo "send fqdn.server-update off;" >> /etc/dhclient.conf
    fi
}

# validate the input
if [[ -z "${1}" ]]; then
	echo "New hostname is not supplied"
	exit 8 
fi

set -e # exit on error
set -u # trigger an error when expanding unset variables

oldName=$(hostname)

# set the hostname
setHostName ${1}
setDNS ${1}

# generate certificates
#read -p "Press ENTER to createSpectreCSR..."
/root/CA/createSpectreCSR.exp ${1}
#read -p "Press ENTER to signSpectreCSR..."
/root/CA/signSpectreCSR.sh
#read -p "Press ENTER to importNewCert..."
/root/CA/importNewCert.sh

#update the hosts file
sudo sed -i "s/${oldName}/${1}/g" /etc/hosts

#update the web service properties
sudo sed -i "s/${oldName}/${1}/g" /usr/share/webapps/spectre/Spectre/WEB-INF/classes/prod/webservice.properties
sudo sed -i "s/${oldName}/${1}/g" /usr/share/webapps/spectre-manager/SpectreManager/WEB-INF/classes/prod/webservice.properties
sudo sed -i "s/${oldName}/${1}/g" /usr/share/webapps/spectre-vcenter/VCenter/WEB-INF/classes/prod/webservice.properties
sudo sed -i "s/${oldName}/${1}/g" /usr/share/tomcatSpectre/work/Catalina/localhost/Spectre/loader/prod/webservice.properties

# update admin portal context
sudo sed -i "s/${oldName}/${1}/g" /usr/share/webapps/spectre-delladminportal/DellAdminPortal/WEB-INF/classes/applicationContext.xml
sudo sed -i "s/${oldName}/${1}/g" /usr/share/webapps/spectre-delladminportal/DellAdminPortal/WEB-INF/classes/applicationContext-security.xml

#update tomcat configuration
sudo sed -i "s/${oldName}/${1}/g" /etc/sysconfig/tomcatSpectre

