#!/bin/env python

import SOAPpy
import curses
import datetime
import fcntl
import getpass_backport
import os
import shutil
import socket
import struct
import subprocess
import sys
import time
import ws_comm

def continue_prompt(message):
    curses.wrapper(wrapped_prompt, message)
    return
    
def wrapped_prompt(window, message):
    curses.curs_set(0)
    window.clear()
    window.addstr(2, 0, message)
    window.addstr(4, 0, "Press <ENTER> to Continue")
    while 1:
        char = window.getch()
        if char == curses.KEY_ENTER or char == 10 :
            break
    curses.curs_set(1)
    return

def change_admin_password(providedPass, newPass):
    sys.stdout.flush()
    saveout = sys.stdout
    fsock = open('/dev/null', 'w')
    try:
        WSDLFILE = 'https://localhost.localdomain/Spectre/SpectreConfigurationService?wsdl'
        NAMESPACE = 'http://pg.dell.com/spectre/spectreconfiguration/ws'
        SOAPACTION = 'http://pg.dell.com/spectre/spectreconfiguration/ws/setAdminPassword'
        _server = SOAPpy.SOAPProxy(WSDLFILE, namespace=NAMESPACE, soapaction=SOAPACTION)
        _server.config.argsOrdering = {'SetAdminPassword': ['currentPassword', 'newPassword']}
        sys.stdout = fsock
        result = _server.SetAdminPassword(currentPassword = providedPass, newPassword = newPass)
        sys.stdout = saveout
    except SOAPpy.Types.faultType, fault:
        sys.stdout = saveout
        fsock.close()
        errormsg = "*ERROR* " + fault['detail']['SpectreFault']['details']
        print errormsg
        if "*ERROR* The password entered did not match the stored password" in errormsg:
            return 1
        else:
            print "General Backend error"
            return 4
    except SOAPpy.Errors.HTTPError:
        sys.stdout = saveout
        fsock.close()
        errormsg = "Services haven't yet initialized. Please try again after a few minutes."
        print errormsg
        return 4
    except:
        sys.stdout = saveout
        fsock.close()
        print "*UNKNOWN ERROR* Password not set"
        return 4     
    sys.stdout = saveout
    
    fsock.close()
    sys.stdout.flush()
    subprocess.Popen(['passwd', '--stdin', 'admin', ], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate(input=newPass)
    #subprocess.Popen(['passwd', '--stdin', 'root', ], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate(input=newPass)
    #subprocess.Popen(['passwd', '--stdin', 'readonly', ], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate(input=newPass)
    #continue_prompt('Password set successfully')
    return 0

def validatePassword(password):
    import re
    
    for i in range(len(password)):
        if password[i].isspace():
            print "*ERROR* Must not contain any space, new line or tab characters"
            return False
    if not re.search(r'\d', password):
        print "*ERROR* Must contain at least one numeric character"
        return False
    if not re.search(r'[A-Z]', password):
        print "*ERROR* Must contain at least one uppercase character"
        return False
    if not re.search(r'[a-z]', password):
        print "*ERROR* Must contain at least one lowercase character"
        return False
    #if re.match('^[\w]+$', password):
    if re.match('^[a-zA-Z0-9]+$', password):
        print "*ERROR* Must contain at least one non-alphanumeric character"
        return False
    if len(password) <8:
        print "*ERROR* Must contain at least 8 characters"
        return False
    return True

def usage():
    print "Usage:"
    print "%s currentPassword newPassword" % sys.argv[0]
    return False

# Custom script returns 0 for success (we change the admin, root and any other passwords)
# Custom script returns 1 for Current password is incorrect and does not match system
# Custom script returns 2 for current and new passwords already match
# Custom script returns 3 for Password does conform to requirements (too short, etc.)
# Custom script returns 4 for general Backend failure
try:
    # Start logging to file
    old_stdout = sys.stdout
    log_file = open("/var/log/change_password.log","w")
    sys.stdout = log_file

    print "Current password is %s" % sys.argv[1]
    print "New password is %s" % sys.argv[2]
    
    errorLevel = 0
    
    if (validatePassword(sys.argv[2]) == False):
        print "Password does conform to requirements"
        errorLevel = 3
    elif sys.argv[1] == "":
        print "Current Password is blank"
        errorLevel = 3
    elif sys.argv[2] == "":
        print "New Password is blank"
        errorLevel = 3
    elif sys.argv[1] == sys.argv[2]:
        errorLevel = 2
        print "*ERROR* New password must be different from the current password"
    else:
        # Password conforms to all the rules, so change it now
        retValue = change_admin_password(sys.argv[1], sys.argv[2])
        print "retValue from change_admin_password is %s" % retValue
        if retValue == 0:
            errorLevel = 0
        elif retValue > 0:
            errorLevel = retValue
        
    print "errorLevel is %s" % errorLevel

    # Close out logging
    sys.stdout = old_stdout
    log_file.close()

    sys.exit(errorLevel)

except IndexError:
    usage()
    sys.exit(3)
