#!/bin/bash

#--------------------------------------------------------------
#  cvinit service luks volume mount script
#
#  Used to mount and unmount an encrypted luks partition using
#  pre-defined keyfiles.  Use for obfuscation - not secure.
#
#  Note: due to cryptsetup version, unable to use --key-file=- 
#        to read stdin, so forced to temporarily write a file.
#--------------------------------------------------------------

ENCRYPTEDFILE_FILEPATH="/usr/share/webapps/spectre/configscripts/pwscv"
KEYFILE1=/usr/share/webapps/spectre/configscripts/spectre_kf_a 
KEYFILE2=/usr/share/webapps/spectre-vcenter/configscripts/DBScripts/spectre_kf_f
KEYFILE3=/usr/share/webapps/spectre-manager/configscripts/spectre_kf_5
LOGFILE=/tmp/cvinit.log
MOUNT_POINT="/mnt/cv"
MAPPER_NAME="cvmapped"

# clear out the log and write the current command
echo "cvinit entered with command " $1 > $LOGFILE  
# changing permissions for log file
chmod 644 $LOGFILE

case "$1" in

   start) 
    # make sure that we are not already mounted
    if ( mount | grep $MOUNT_POINT > /dev/null ); then
        echo "A mount already exists at:" $MOUNT_POINT >> $LOGFILE
        exit 70
    fi
    
    # make sure that our key files exist
    if [[ ! ( -e $KEYFILE1 && -e $KEYFILE2 && -e $KEYFILE3 ) ]]; then
        echo "Invalid key source" >> $LOGFILE
        exit 70
    fi

    # find an unused loop device
    LOOP_DEVICE=$(losetup -f)
    echo "Using loop device:" $LOOP_DEVICE >> $LOGFILE

    # attach the file we created to the loop device
    losetup $LOOP_DEVICE $ENCRYPTEDFILE_FILEPATH >> $LOGFILE 2>&1

    # confirm the previous step is completed successfully
    # zero is returned for success.
    if (( $? > 0 )); then
        echo "Failed to attach file to loop device" >> $LOGFILE 
        exit 70
    fi

    # combine the keyfile into a 28 byte keyfile
    KEYFILE=/tmp/a1932707-e8f4-4672-992a-ef84bebe45f1
    cat $KEYFILE1 $KEYFILE2 $KEYFILE3 > $KEYFILE
    
    # add the last 8 bytes to the keyfile - same as used when generating.
    echo "RvZeA9Z!" >> $KEYFILE

    # open a mapping to the luks partition to the device using the key
    cryptsetup luksOpen --readonly --key-file $KEYFILE $LOOP_DEVICE $MAPPER_NAME >> $LOGFILE 2>&1
       
    # remove the keyfile
    echo "removing the keyfile" >> $LOGFILE
    rm -f $KEYFILE >> $LOGFILE 2>&1

    # check the file system
    echo "checking the filesystem" >> $LOGFILE
    e2fsck /dev/mapper/$MAPPER_NAME >> $LOGFILE 2>&1

    # create the directory if it doesn't already exist
    if [[ ! -d $MOUNT_POINT ]]; then
        echo "removing the mount point" >> $LOGFILE
        mkdir $MOUNT_POINT >> $LOGFILE 2>&1
    fi

    echo "mounting the file system" >> $LOGFILE
    mount -t ext2 /dev/mapper/$MAPPER_NAME $MOUNT_POINT >> $LOGFILE 2>&1
    RETVAL=0
   ;;

   stop)
    # tear down the file if it is mapped
    if( mount | grep $MOUNT_POINT > /dev/null ); then
        umount $MOUNT_POINT >> $LOGFILE 2>&1
    fi
    
    # if we can't unmount, then stop
    if (( $? > 0 )); then
        echo "failed to stop. Exiting" >> $LOGFILE
        exit 70
    fi

    # close/detach the encrypted partition
    cryptsetup luksClose $MAPPER_NAME  >> $LOGFILE 2>&1

    # unmount the loop device if it is used
    (losetup -a | grep $ENCRYPTEDFILE_FILEPATH | awk -F":" '{print $1}') | while IFS= read -r LOOP_DEVICE;
    do
        echo "unmounting loop device:" $LOOP_DEVICE >> $LOGFILE
        losetup -d $LOOP_DEVICE >> $LOGFILE 2>&1
    done

    # if the mount point directory exists, remove it
    if [[ -d $MOUNT_POINT ]]; then
        rm -fr $MOUNT_POINT >> $LOGFILE 2>&1
    fi
    RETVAL=0
   ;;

 *)
    echo $"Usage: $0 {start|stop}"
    RETVAL=1
esac

exit $RETVAL
