#!/usr/bin/python2

import SOAPpy
import curses
import datetime
import fcntl
import getpass_backport
import os
import shutil
import socket
import struct
import subprocess
import sys
import time
import ws_comm

menu_items = [
    "Configure Network",
    "Change Admin Password",
    "Set Time Zone",
    "Reboot this Virtual Appliance",
    "Reset this Virtual Appliance to Factory Settings",
    "Refresh",
    "Logout",
    ]
num_items = 7


def clearscreen():
    os.system('clear')

def get_ip_address(ifname):
    try:
        s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
        return socket.inet_ntoa(fcntl.ioctl(
            s.fileno(),
            0x8915,  # SIOCGIFADDR
            struct.pack('256s', ifname[:15])
        )[20:24])
    except IOError:
        return '<Not Available>'

def display_menu(window, y, x, items, selection):
    index = 0
    for item in items:
        if index == selection:
            window.addstr(y, x, item, curses.A_REVERSE)
        else:
            window.addstr(y, x, item)
        index += 1
        y += 1

def main_menu(window):
    curses.curs_set(0)
    window.clear()
    window.addstr(0, 0, "OpenManage Integration Virtual Appliance")
    window.addstr(2, 0, "Admin Portal:")
    window.addstr(3, 4, "https://%s/DellAdminPortal/index.html" % get_ip_address('eth0'))
    window.addstr(15, 0, "Arrow keys to navigate")
    window.addstr(16, 0, "<ENTER> to select")
    selection = 0
    while 1:
        display_menu(window, 6, 2, menu_items, selection)
        window.refresh()
        char = window.getch()
        if char == curses.KEY_UP: selection -= 1
        if char == curses.KEY_DOWN: selection += 1
        if selection < 0: selection = 0
        if selection >= num_items: selection = num_items - 1
        if char == curses.KEY_ENTER or char == 10 : break
    curses.curs_set(1)
    return selection

def continue_prompt(message):
    curses.wrapper(wrapped_prompt, message)
    return
    
def wrapped_prompt(window, message):
    curses.curs_set(0)
    window.clear()
    window.addstr(2, 0, message)
    window.addstr(4, 0, "Press <ENTER> to Continue")
    while 1:
        char = window.getch()
        if char == curses.KEY_ENTER or char == 10 :
            break
    curses.curs_set(1)
    return

def validatePassword(password):
    import re
    
    for i in range(len(password)):
        if password[i].isspace():
            print "*ERROR* Must not contain any space, new line or tab characters"
            return False
    if not re.search(r'\d', password):
        print "*ERROR* Must contain at least one numeric character"
        return False
    if not re.search(r'[A-Z]', password):
        print "*ERROR* Must contain at least one uppercase character"
        return False
    if not re.search(r'[a-z]', password):
        print "*ERROR* Must contain at least one lowercase character"
        return False
    #if re.match('^[\w]+$', password):
    if re.match('^[a-zA-Z0-9]+$', password):
        print "*ERROR* Must contain at least one non-alphanumeric character"
        return False
    if len(password) <8:
        print "*ERROR* Must contain at least 8 characters"
        return False
    return True
    
def change_pw(query_pass):
    clearscreen()
    print ; print ; print
    sys.stdout.flush()
    if query_pass == True:
        providedPass = getpass_backport.getpass(prompt="Enter current Admin password: ")
    else:
        providedPass = '=kz+D#X-8|ouAe-e'
    newAdminPass = getpass_backport.getpass(prompt="\n8 characters minimum, a number, a symbol, and both capital and lower-case lettering are required.\nEnter new Admin password: ")
    confirmAdminPass = getpass_backport.getpass(prompt="Please confirm new Admin password: ")
    if newAdminPass == confirmAdminPass:
        sys.stdout.flush()
    else:
        continue_prompt('Provided Passwords Do Not Match')
        return False
        
    if validatePassword(newAdminPass) == False:
        return False
       
    newROPass = getpass_backport.getpass(prompt="\n8 characters minimum, a number, a symbol, and both capital and lower-case lettering are required.\nEnter new password for readonly user: ")
    confirmROPass = getpass_backport.getpass(prompt="Please confirm new password for readonly user: ")
    if newROPass == confirmROPass:
        sys.stdout.flush()
    else:
        continue_prompt('Provided Passwords Do Not Match')
        return False
        
    if validatePassword(newROPass) == False:
        return False

    saveout = sys.stdout
    fsock = open('/dev/null', 'w')
    try:
        WSDLFILE = 'https://localhost.localdomain/Spectre/SpectreConfigurationService?wsdl'
        NAMESPACE = 'http://pg.dell.com/spectre/spectreconfiguration/ws'
        SOAPACTION = 'http://pg.dell.com/spectre/spectreconfiguration/ws/setAdminPassword'
        _server = SOAPpy.SOAPProxy(WSDLFILE, namespace=NAMESPACE, soapaction=SOAPACTION)
        _server.config.argsOrdering = {'SetAdminPassword': ['currentPassword', 'newPassword']}
        sys.stdout = fsock
        result = _server.SetAdminPassword(currentPassword = providedPass, newPassword = newAdminPass)
        sys.stdout = saveout
    except SOAPpy.Types.faultType, fault:
        sys.stdout = saveout
        fsock.close()
        errormsg = "*ERROR* " + fault['detail']['SpectreFault']['details']
        continue_prompt(errormsg + '\nPassword not set')
        return False
    except SOAPpy.Errors.HTTPError:
        sys.stdout = saveout
        fsock.close()
        errormsg = "Services haven't yet initialized. Please try again after a few minutes."
        continue_prompt(errormsg + '\nPassword not set')
        return False
    except:
        sys.stdout = saveout
        fsock.close()
        continue_prompt('*UNKNOWN ERROR* Password not set')
        return False     
    sys.stdout = saveout
    
    fsock.close()
    sys.stdout.flush()
    subprocess.Popen(['passwd', '--stdin', 'admin', ], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate(input=newAdminPass)
    subprocess.Popen(['passwd', '--stdin', 'readonly', ], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate(input=newROPass)
    subprocess.Popen(['usermod', '-s', '/sbin/nologin', 'root', ], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()
    subprocess.Popen(['groupadd', 'SpectreExec', ], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()
    subprocess.Popen(['usermod', '-a', '-G', 'SpectreExec', 'root', ], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()
    subprocess.Popen(['usermod', '-a', '-G', 'SpectreExec', 'admin', ], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()
    subprocess.Popen(['usermod', '-a', '-G', 'SpectreExec', 'tomcat', ], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()

    subprocess.Popen(['chgrp', 'SpectreExec', '/usr/share/webapps/spectre-security/SpectreSecurity/WEB-INF/classes/log4j.xml', ], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()
    subprocess.Popen(['chmod', '640', '/usr/share/webapps/spectre-security/SpectreSecurity/WEB-INF/classes/log4j.xml', ], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()

    subprocess.Popen(['chgrp', 'SpectreExec', '/usr/share/webapps/spectre/Spectre/WEB-INF/classes/log4j.xml', ], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()
    subprocess.Popen(['chmod', '640', '/usr/share/webapps/spectre/Spectre/WEB-INF/classes/log4j.xml ', ], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()

    subprocess.Popen(['chgrp', 'SpectreExec', '/usr/share/webapps/spectre-vcenter/VCenter/WEB-INF/classes/log4j.xml', ], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()
    subprocess.Popen(['chmod', '640', '/usr/share/webapps/spectre-vcenter/VCenter/WEB-INF/classes/log4j.xml', ], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()

    subprocess.Popen(['service', 'tomcatSpectre', 'restart', ], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()
    subprocess.Popen(['service', 'postgresql-9.6', 'restart', ], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()
    continue_prompt('Password set successfully')
    return True

def getContentsFromFile(filePath):
    infile = open(filePath, "r")
    contents = infile.read()
    infile.close()
    return contents

def writeContentsToFile(filePath, contents):
    infile = open(filePath, "w")
    infile.write(contents)
    infile.close()
    return

def hasDNSFilesChanged():
    secondsToCheck = 3
    resolveFile = "/etc/resolv.conf"
    resolveModifiedTime = os.path.getmtime(resolveFile)
    networkFile = "/etc/sysconfig/network"
    networkModifiedTime = os.path.getmtime(networkFile)
    eth0File = "/etc/sysconfig/network-scripts/ifcfg-eth0"
    eth0ModifiedTime = os.path.getmtime(eth0File)
    t = datetime.datetime.now()
    currentEpochTime = time.mktime(t.timetuple())
    if currentEpochTime - resolveModifiedTime < secondsToCheck:
        return True
    elif currentEpochTime - networkModifiedTime < secondsToCheck:
        return True
    elif currentEpochTime - eth0ModifiedTime < secondsToCheck:
        return True
    else:
        return False

def hasHostnameChanged():
    filePath = "/root/.hostname"
    currentHostOutput= subprocess.Popen(['hostname', ], stdout=subprocess.PIPE).communicate()
    currentHostname = currentHostOutput[0].strip().lower()
    if os.path.isfile(filePath):
        oldHostname = getContentsFromFile(filePath).strip().lower()
    else:
        oldHostname = "localhost"
    if currentHostname == oldHostname:
        return False
    else:
        writeContentsToFile(filePath, currentHostname)
        return True

def launch_network_config():
    subprocess.Popen(['/usr/sbin/system-config-network-tui', ]).wait()
    if hasDNSFilesChanged():
        #backup resolve.conf first since dhcp will clear it.
        shutil.copy2('/etc/resolv.conf', '/etc/resolv.conf.bak')
        subprocess.Popen(['/sbin/service', 'network', 'restart', ]).wait()
        shutil.copy2('/etc/resolv.conf.bak', '/etc/resolv.conf')
        if hasHostnameChanged():
            regen_cert()
            subprocess.Popen(['/sbin/service', 'httpd', 'restart', ]).wait()
        ws_comm.restartSnmpListener()
        

def regen_cert():
    print "Generating certificate with hostname"
    sys.stdout.flush()
    try:
        output = subprocess.Popen(['hostname', ], stdout=subprocess.PIPE).communicate()
        if subprocess.Popen(['/root/CA/createSpectreCSR.exp', output[0], ], stdout=subprocess.PIPE).wait() != 0:
            raise Exception
        if subprocess.Popen(['/root/CA/signSpectreCSR.sh', ], stdout=subprocess.PIPE).wait() != 0:
            raise Exception
        if subprocess.Popen(['/root/CA/importNewCert.sh', ], stdout=subprocess.PIPE).wait() != 0:
            raise Exception
    except:
        print "An error occured generating the certificate"
    sys.stdout.flush()

def set_time_zone():
    clearscreen()
    output = subprocess.Popen(['date', ], stdout=subprocess.PIPE).communicate()
    datemessage = "Current time is:\n" + output[0] + "\n*NOTE* System will have to restart to properly update the time for all services.\n Do you wish to continue?"
    if verify_with_user(datemessage):
        try:
            oldContents = getContentsFromFile('/etc/sysconfig/clock').strip()
        except IOError:
            oldContents = ''
            
        subprocess.Popen(['/usr/sbin/timeconfig', ]).wait()
        try:
            newContents = getContentsFromFile('/etc/sysconfig/clock').strip()
        except IOError:
            newContents = ''
            
        if newContents != oldContents and newContents != '': 
            subprocess.Popen(['/sbin/shutdown', '-r', 'now'] ).wait()
        else:
            continue_prompt('No Timezone changes made.')
    else:
        continue_prompt('Timezone change cancelled.')

def verify_with_user(question):
    print ; print
    print question
    sys.stdout.flush()
    prompt = raw_input( 'y or n? : ')
    return prompt == "y" or prompt == "Y"

def reboot_spectre_appliance():  
    clearscreen()
    if verify_with_user('If there are any processes running\non this appliance, they will be\nterminated by this action\n\nAre you sure you wish to do this?'):
        subprocess.Popen(['/sbin/shutdown', '-r', 'now'] ).wait()
    else:
        continue_prompt('Reboot cancelled.')

def reset_spectre_appliance():
    clearscreen()
    print "****************************************"
    print "**             NOTICE                 **"
    print "****************************************"
    print "This operation is completely irreversible." 
    print ""    
    print "if you continue you will completely reset"
    print "*this* appliance to its original settings"
    print "and all the changes you have made to this"
    print "appliance will be lost."
    print "****************************************"
    print "****************************************"

    if verify_with_user('Are you sure you want to reset this \nappliance to factory settings?'):
        pw = getpass_backport.getpass()
        print 'Attempting to unregister with all VMware vCenters...'
        sys.stdout.flush()
        if ws_comm.unregister_vcenters(pw) is False:
            continue_prompt('Failed Unregistering vCenters')
            return
        print 'Finished unregistering vCenters'
        sys.stdout.flush()
        print ; print ; print
        print 'Resetting this appliance...'
        sys.stdout.flush()        
        pobj = subprocess.Popen(['/usr/share/webapps/spectre/configscripts/resetApplianceToFactorySettings.sh'], )
        pobj.wait()
        if pobj.returncode == 0:
            pass
        else:
            continue_prompt('Shutdown sequence failed! Aborting')        
    else:
        continue_prompt('Reset to factory settings cancelled.')


ws_comm.send_login_event(get_ip_address('eth0'))    
while True:
    if not os.path.isfile('/root/.pwset'):
        while not change_pw(False):
            pass
    open('/root/.pwset', 'w').close()
    subprocess.Popen(['sudo', '/usr/sbin/init_shell']).wait()
    break

    #selection = curses.wrapper(main_menu)
    #if selection == 0: launch_network_config()
    #if selection == 1: change_pw(True)
    #if selection == 2: set_time_zone()
    #if selection == 3: reboot_spectre_appliance()
    #if selection == 4: reset_spectre_appliance()
    #if selection == 5: pass
    #if selection == 6: break
