-- Table: firmware_update_entity

-- DROP TABLE firmware_update_entity;

CREATE TABLE firmware_update_entity
(
  id bigint NOT NULL,
  idracip character varying(256),
  biosupgradestatus character varying(128),
  idracupgradestatus character varying,
  lcupgradestatus character varying,
  uuid character varying(50),
  idracusername character varying(128),
  idracpassword character varying(128),
  host character varying(256),
  networkconsoleaddress character varying(256),
  firmwareupdatestatus character varying(128),
  sourcetype character varying(128),
  creationtime timestamp without time zone,
  rebootafterupdate boolean,  
  CONSTRAINT p_key PRIMARY KEY (id)
)
WITHOUT OIDS;
ALTER TABLE firmware_update_entity OWNER TO spectre_admin;

-- Sequence: seq_firmwareupdate

-- DROP SEQUENCE seq_firmwareupdate;

CREATE SEQUENCE seq_firmwareupdate
  INCREMENT 1
  MINVALUE 1000
  MAXVALUE 999999999999999999
  START 1006
  CACHE 1;
ALTER TABLE seq_firmwareupdate OWNER TO spectre_admin;

ALTER TABLE deployable_server ADD COLUMN media_type character varying(64);


-- Table: host_compliance

-- DROP TABLE host_compliance;

CREATE TABLE host_compliance
(
  host_compliance_id integer NOT NULL,
  host_ip_name character varying(30),
  omsa_status character varying(25),
  omsa_version character varying(25),
  last_run_date timestamp without time zone,
  connection_profile_id integer,
  csior_status character varying(25),
  reboot character varying(25),
  hypervisor_version character varying(30),
  hypervisor_status character varying(20),
  CONSTRAINT host_compliance_pk PRIMARY KEY (host_compliance_id),
  CONSTRAINT "connection_profile_FK" FOREIGN KEY (connection_profile_id)
      REFERENCES connection_profile (connection_profile_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT host_ipname_unique UNIQUE (host_ip_name)
)
WITHOUT OIDS;
ALTER TABLE host_compliance OWNER TO spectre_admin;


-- Sequence: seq_host_compliance

-- DROP SEQUENCE seq_host_compliance;

CREATE SEQUENCE seq_host_compliance
  INCREMENT 1
  MINVALUE 1000
  MAXVALUE 999999999999
  START 1001
  CACHE 1;
ALTER TABLE seq_host_compliance OWNER TO spectre_admin;

CREATE TABLE hardware_inventory_12g
(
  id bigint NOT NULL,
  inventory_xml character varying(1024000),
  power_monitoring_xml character varying(1024000),
  storage_xml character varying(1024000),
  hardware_inventory_xml character varying(1024000),
  CONSTRAINT hardware_inventory_12g_pkey PRIMARY KEY (id)
)
WITHOUT OIDS;
ALTER TABLE hardware_inventory_12g OWNER TO spectre_admin;

CREATE SEQUENCE SEQ_HARDWARE_INVENTORY_12G
  MINVALUE 1000
  MAXVALUE 999999999999
  START WITH 1000
  NO CYCLE;
  ALTER TABLE SEQ_HARDWARE_INVENTORY_12G OWNER TO spectre_admin;
  
Alter table hardware_inventory Add Column hardware_inventory_12g_id bigint;

Alter table hardware_inventory Add CONSTRAINT hardware_inventory_12g_fkey FOREIGN KEY (hardware_inventory_12g_id)
      REFERENCES hardware_inventory_12g (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION;  
      
      
Alter table device Add Column is_12g boolean;
Alter table server_details Add Column idrac_component_id character varying(64);

-- Tables for licensing support
CREATE TABLE device_license
(
  entitlementid character varying(255) NOT NULL,
  hostid character varying(255) NOT NULL,
  idracip character varying(255) NOT NULL,
  evallicensetimeremaining character varying(255),
  licenseattributes character varying(255),
  licensedescription character varying(1024),
  licenseduration character varying(255),
  licenseenddate character varying(255),
  licensefile character varying(524288),
  licenseinstalldate character varying(255),
  licenseprimarystatus character varying(255),
  licensesolddate character varying(255),
  licensestartdate character varying(255),
  licensestatusmessage character varying(1024),
  licensetype character varying(255),
  feature_bits character varying(250),
  service_tag character varying(30),
  CONSTRAINT device_license_pkey PRIMARY KEY (entitlementid, hostid)
)
WITHOUT OIDS;
ALTER TABLE device_license OWNER TO spectre_admin;

CREATE TABLE licensable_device
(
  id bigint NOT NULL,
  fqdd character varying(255),
  deviceid character varying(255),
  devicestatus character varying(255),
  devicestatusmessage character varying(1024),
  model character varying(255),
  entitlementid character varying(255),
  hostid character varying(255),
  CONSTRAINT licensable_device_pkey PRIMARY KEY (id),
  CONSTRAINT fk_device_license FOREIGN KEY (entitlementid, hostid)
      REFERENCES device_license (entitlementid, hostid) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITHOUT OIDS;
ALTER TABLE licensable_device OWNER TO spectre_admin;
ALTER TABLE DEPLOYABLE_GROUP ADD COLUMN vcenter_network_address character varying(255) NOT NULL DEFAULT 'UNKNOWN';
ALTER TABLE deployable_group DROP CONSTRAINT deployable_group_name_key;
ALTER TABLE deployable_group ADD CONSTRAINT deployable_group_name_key UNIQUE (name, vcenter_network_address);
Alter table server_details Add Column sdcard_avail boolean NOT NULL DEFAULT false;
Alter table server_details DROP CONSTRAINT server_details_service_tag_key;
Alter table server_details ADD CONSTRAINT server_details_service_tag_key UNIQUE (service_tag, ip_address);

CREATE SEQUENCE seq_task_svctag_map
  INCREMENT 1
  MINVALUE 1000
  MAXVALUE 999999999999
  START 1001
  CACHE 1;
ALTER TABLE seq_task_svctag_map OWNER TO spectre_admin;

CREATE TABLE task_svctag_map
(
  map_id bigint,
  task_id bigint,
  service_tag character varying(7),
  ip_address character varying(128),
  last_update_time timestamp without time zone,
  task_status character varying(255),
  CONSTRAINT map_id_pkey PRIMARY KEY (map_id),
  CONSTRAINT "task_id_foreignKey" FOREIGN KEY (task_id)
      REFERENCES task (task_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITHOUT OIDS;
ALTER TABLE task_svctag_map OWNER TO spectre_admin;

--For 12G events changes

ALTER TABLE event_definition Alter column format_string TYPE character varying(2560);

ALTER table event_log alter column message TYPE character varying(2560);

alter table snmp_event  add column format_string character varying(2560);

UPDATE snmp_event SET format_string = (SELECT format_string from event_definition WHERE event_definition.event_definition_id = snmp_event.event_definition_id )
WHERE EXISTS (SELECT 1 from event_definition WHERE event_definition.event_definition_id = snmp_event.event_definition_id);

alter table event_definition drop column format_string;

Alter table server_details Add Column device_license boolean NOT NULL DEFAULT true;
Alter table server_details Add Column system_12G boolean NOT NULL DEFAULT false;

--Add new column for lc_code and lc_string in task_execution_detail_history
ALTER TABLE task_execution_detail_history ADD COLUMN lc_error_code character varying(10);
ALTER TABLE task_execution_detail_history ADD COLUMN lc_error_string character varying(2000);

DROP table task_hostlist;