--Entries for Quartz Scheduler 2.x Updates
--migration guide at http://www.quartz-scheduler.org/documentation/quartz-2.x/migration-guide.html
--drop tables that are no longer used - migration guide
drop table qrtz_job_listeners;
drop table qrtz_trigger_listeners;
-- drop columns that are no longer used - migration guide
alter table qrtz_job_details drop column is_volatile;
alter table qrtz_triggers drop column is_volatile;
alter table qrtz_fired_triggers drop column is_volatile;
-- add new columns that replace the 'is_stateful' column - migration guide
alter table qrtz_job_details add column is_nonconcurrent bool;
alter table qrtz_job_details add column is_update_data bool;
update qrtz_job_details set is_nonconcurrent = is_stateful;
update qrtz_job_details set is_update_data = is_stateful;
alter table qrtz_job_details drop column is_stateful;
alter table qrtz_fired_triggers add column is_nonconcurrent bool;
alter table qrtz_fired_triggers add column is_update_data bool;
update qrtz_fired_triggers set is_nonconcurrent = is_stateful;
update qrtz_fired_triggers set is_update_data = is_stateful;
alter table qrtz_fired_triggers drop column is_stateful;
-- add new 'sched_name' column to all tables - migration guide - customized name for Spectre
alter table qrtz_blob_triggers add column sched_name varchar(120) not null DEFAULT 'taskSchedulerFactoryBean';
alter table qrtz_calendars add column sched_name varchar(120) not null DEFAULT 'taskSchedulerFactoryBean';
alter table qrtz_cron_triggers add column sched_name varchar(120) not null DEFAULT 'taskSchedulerFactoryBean';
alter table qrtz_fired_triggers add column sched_name varchar(120) not null DEFAULT 'taskSchedulerFactoryBean';
alter table qrtz_job_details add column sched_name varchar(120) not null DEFAULT 'taskSchedulerFactoryBean';
alter table qrtz_locks add column sched_name varchar(120) not null DEFAULT 'taskSchedulerFactoryBean';
alter table qrtz_paused_trigger_grps add column sched_name varchar(120) not null DEFAULT 'taskSchedulerFactoryBean';
alter table qrtz_scheduler_state add column sched_name varchar(120) not null DEFAULT 'taskSchedulerFactoryBean';
alter table qrtz_simple_triggers add column sched_name varchar(120) not null DEFAULT 'taskSchedulerFactoryBean';
alter table qrtz_triggers add column sched_name varchar(120) not null DEFAULT 'taskSchedulerFactoryBean';
-- drop all primary and foreign key constraints, so that we can define new ones - migration guide
alter table qrtz_triggers drop constraint qrtz_triggers_job_name_fkey;
alter table qrtz_blob_triggers drop constraint qrtz_blob_triggers_pkey;
alter table qrtz_blob_triggers drop constraint qrtz_blob_triggers_trigger_name_fkey;
alter table qrtz_simple_triggers drop constraint qrtz_simple_triggers_pkey;
alter table qrtz_simple_triggers drop constraint qrtz_simple_triggers_trigger_name_fkey;
alter table qrtz_cron_triggers drop constraint qrtz_cron_triggers_pkey;
alter table qrtz_cron_triggers drop constraint qrtz_cron_triggers_trigger_name_fkey;
alter table qrtz_job_details drop constraint qrtz_job_details_pkey;
alter table qrtz_job_details add primary key (sched_name, job_name, job_group);
alter table qrtz_triggers drop constraint qrtz_triggers_pkey;
-- add all primary and foreign key constraints, based on new columns - migration guide
alter table qrtz_triggers add primary key (sched_name, trigger_name, trigger_group);
alter table qrtz_triggers add foreign key (sched_name, job_name, job_group) references qrtz_job_details(sched_name, job_name, job_group);
alter table qrtz_blob_triggers add primary key (sched_name, trigger_name, trigger_group);
alter table qrtz_blob_triggers add foreign key (sched_name, trigger_name, trigger_group) references qrtz_triggers(sched_name, trigger_name, trigger_group);
alter table qrtz_cron_triggers add primary key (sched_name, trigger_name, trigger_group);
alter table qrtz_cron_triggers add foreign key (sched_name, trigger_name, trigger_group) references qrtz_triggers(sched_name, trigger_name, trigger_group);
alter table qrtz_simple_triggers add primary key (sched_name, trigger_name, trigger_group);
alter table qrtz_simple_triggers add foreign key (sched_name, trigger_name, trigger_group) references qrtz_triggers(sched_name, trigger_name, trigger_group);
alter table qrtz_fired_triggers drop constraint qrtz_fired_triggers_pkey;
alter table qrtz_fired_triggers add primary key (sched_name, entry_id);
alter table qrtz_calendars drop constraint qrtz_calendars_pkey;
alter table qrtz_calendars add primary key (sched_name, calendar_name);
alter table qrtz_locks drop constraint qrtz_locks_pkey;
alter table qrtz_locks add primary key (sched_name, lock_name);
alter table qrtz_paused_trigger_grps drop constraint qrtz_paused_trigger_grps_pkey;
alter table qrtz_paused_trigger_grps add primary key (sched_name, trigger_group);
alter table qrtz_scheduler_state drop constraint qrtz_scheduler_state_pkey;
alter table qrtz_scheduler_state add primary key (sched_name, instance_name);
-- add new simprop_triggers table - migration guide
CREATE TABLE qrtz_simprop_triggers
 (          
    SCHED_NAME VARCHAR(120) NOT NULL,
    TRIGGER_NAME VARCHAR(200) NOT NULL,
    TRIGGER_GROUP VARCHAR(200) NOT NULL,
    STR_PROP_1 VARCHAR(512) NULL,
    STR_PROP_2 VARCHAR(512) NULL,
    STR_PROP_3 VARCHAR(512) NULL,
    INT_PROP_1 INT NULL,
    INT_PROP_2 INT NULL,
    LONG_PROP_1 BIGINT NULL,
    LONG_PROP_2 BIGINT NULL,
    DEC_PROP_1 NUMERIC(13,4) NULL,
    DEC_PROP_2 NUMERIC(13,4) NULL,
    BOOL_PROP_1 BOOL NULL,
    BOOL_PROP_2 BOOL NULL,
    PRIMARY KEY (SCHED_NAME,TRIGGER_NAME,TRIGGER_GROUP),
    FOREIGN KEY (SCHED_NAME,TRIGGER_NAME,TRIGGER_GROUP)
    REFERENCES QRTZ_TRIGGERS(SCHED_NAME,TRIGGER_NAME,TRIGGER_GROUP)
)
WITH (
  OIDS=FALSE
);
ALTER TABLE "qrtz_simprop_triggers" OWNER TO spectre_admin;
-- create indexes for faster queries - migration guide
create index idx_qrtz_j_req_recovery on qrtz_job_details(SCHED_NAME,REQUESTS_RECOVERY);
create index idx_qrtz_j_grp on qrtz_job_details(SCHED_NAME,JOB_GROUP);
create index idx_qrtz_t_j on qrtz_triggers(SCHED_NAME,JOB_NAME,JOB_GROUP);
create index idx_qrtz_t_jg on qrtz_triggers(SCHED_NAME,JOB_GROUP);
create index idx_qrtz_t_c on qrtz_triggers(SCHED_NAME,CALENDAR_NAME);
create index idx_qrtz_t_g on qrtz_triggers(SCHED_NAME,TRIGGER_GROUP);
create index idx_qrtz_t_state on qrtz_triggers(SCHED_NAME,TRIGGER_STATE);
create index idx_qrtz_t_n_state on qrtz_triggers(SCHED_NAME,TRIGGER_NAME,TRIGGER_GROUP,TRIGGER_STATE);
create index idx_qrtz_t_n_g_state on qrtz_triggers(SCHED_NAME,TRIGGER_GROUP,TRIGGER_STATE);
create index idx_qrtz_t_next_fire_time on qrtz_triggers(SCHED_NAME,NEXT_FIRE_TIME);
create index idx_qrtz_t_nft_st on qrtz_triggers(SCHED_NAME,TRIGGER_STATE,NEXT_FIRE_TIME);
create index idx_qrtz_t_nft_misfire on qrtz_triggers(SCHED_NAME,MISFIRE_INSTR,NEXT_FIRE_TIME);
create index idx_qrtz_t_nft_st_misfire on qrtz_triggers(SCHED_NAME,MISFIRE_INSTR,NEXT_FIRE_TIME,TRIGGER_STATE);
create index idx_qrtz_t_nft_st_misfire_grp on qrtz_triggers(SCHED_NAME,MISFIRE_INSTR,NEXT_FIRE_TIME,TRIGGER_GROUP,TRIGGER_STATE);
create index idx_qrtz_ft_trig_inst_name on qrtz_fired_triggers(SCHED_NAME,INSTANCE_NAME);
create index idx_qrtz_ft_inst_job_req_rcvry on qrtz_fired_triggers(SCHED_NAME,INSTANCE_NAME,REQUESTS_RECOVERY);
create index idx_qrtz_ft_j_g on qrtz_fired_triggers(SCHED_NAME,JOB_NAME,JOB_GROUP);
create index idx_qrtz_ft_jg on qrtz_fired_triggers(SCHED_NAME,JOB_GROUP);
create index idx_qrtz_ft_t_g on qrtz_fired_triggers(SCHED_NAME,TRIGGER_NAME,TRIGGER_GROUP);
create index idx_qrtz_ft_tg on qrtz_fired_triggers(SCHED_NAME,TRIGGER_GROUP);


      
ALTER TABLE firmware_group ADD COLUMN enter_maintenance_mode_option character varying(256) DEFAULT 'Default';
ALTER TABLE firmware_group ADD COLUMN evacuate_vms boolean DEFAULT false;
ALTER TABLE firmware_group ADD COLUMN check_prereq boolean DEFAULT false;
ALTER TABLE firmware_group ADD COLUMN update_type character varying(60) DEFAULT 'UNKNOWN';
ALTER TABLE firmware_group ADD COLUMN time_out integer DEFAULT 60;

--Entries for vsan status in Spectre DB
ALTER TABLE profile_console_entity ADD COLUMN vsan_host_status boolean DEFAULT false;
ALTER TABLE profile_console_entity ADD COLUMN host_parent_type character varying(256) DEFAULT 'DEFAULT';
ALTER TABLE profile_console_entity ADD COLUMN host_parent_id character varying(256) DEFAULT 'Default';


DROP TABLE repository_profile_table;

CREATE TABLE repository_profile_table
(
  r_profile_id bigint NOT NULL,
  r_name character varying(255),
  r_description character varying(512),
  r_type character varying(255),
  r_url character varying(255),
  r_username character varying(255),
  r_password character varying(255),
  r_lastRefreshstatus character varying(255),
  r_lastSuccessfulRefreshTime timestamp without time zone,
  r_sharetype  character varying(32),
  r_catalog_byte_array bytea,
  r_vcenter_ip character varying(255),
  r_vcenter_name character varying(255),
  r_last_modified_date timestamp without time zone,
  r_last_modified_by character varying (255),
  r_creation_date timestamp without time zone NOT NULL,
  r_refresh_catalog boolean,
  PRIMARY KEY (r_profile_id)
)
WITHOUT OIDS;
ALTER TABLE repository_profile_table OWNER TO spectre_admin;

-- Table: software_identity

-- DROP TABLE software_identity;

CREATE TABLE driver_identity
(
  id bigint NOT NULL,
  device_id bigint NOT NULL,
  last_update timestamp without time zone,
  vcenter_ip character varying(50),
  driver_name character varying(50),
  driver_version character varying(50),
  vendor_name character varying(20),
  acceptance_level character varying(20),
  install_date date,
  CONSTRAINT driver_identity_pkey PRIMARY KEY (id),
  CONSTRAINT fk_device_device_id foreign key (device_id) references device(device_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION 
)
WITHOUT OIDS;
ALTER TABLE driver_identity OWNER TO spectre_admin;

--==========================================================================
--
--  NAME       : SEQ_DRIVER_IDENTITY
--  Object Type: SEQUENCE
--
--==========================================================================
--DROP SEQUENCE SEQ_DRIVER_IDENTITY;

CREATE SEQUENCE SEQ_DRIVER_IDENTITY
  MINVALUE 1000
  MAXVALUE 999999999999999999
  START WITH 1000
  NO CYCLE;
ALTER TABLE SEQ_DRIVER_IDENTITY OWNER TO spectre_admin;

---------------------------------------------------
-- Cluster Profile Related Tables added by Karthik
---------------------------------------------------

CREATE TABLE cluster_table
(
  cluster_table_id bigint NOT NULL,
  cluster_name character varying(256) NOT NULL,
  cluster_id character varying(256) NOT NULL,
  cluster_vcenter_address character varying(256), 
  cluster_vsan boolean DEFAULT false,
  cluster_drs boolean DEFAULT false,
  cluster_pha boolean DEFAULT false,
  cluster_ha boolean DEFAULT false,
  cluster_no_of_hosts bigint DEFAULT 0,
  cluster_no_of_hosts_mm bigint DEFAULT 0,
  cluster_no_of_fault_domains bigint DEFAULT 0,
  update_date timestamp without time zone,
   
  CONSTRAINT pk_cluster_id PRIMARY KEY (cluster_table_id)
)
WITH (
  OIDS=FALSE
);

ALTER TABLE cluster_table
  OWNER TO spectre_admin;

CREATE SEQUENCE SEQ_CLUSTER_TABLE
  MINVALUE 1000
  MAXVALUE 999999999999999999
  START WITH 1000
  NO CYCLE;
ALTER TABLE SEQ_CLUSTER_TABLE OWNER TO spectre_admin;  
  

CREATE TABLE cluster_profile
(
  cp_id bigint NOT NULL,
  cp_name character varying(256) NOT NULL,
  cp_description character varying(1024),
  cp_creation_time timestamp without time zone,
  cp_update_time timestamp without time zone,
  cp_updated_by character varying(250) NOT NULL,
  cp_vmmserveraddress character varying(256),
  cp_schedule character varying(255),
  cp_fw_repo_profile_id bigint,
  cp_fw_repo_catalog_snapshot bytea,
  cp_fw_snapshot_update_time timestamp without time zone,
  cp_dr_repo_profile_id bigint,
  cp_dr_repo_catalog_snapshot bytea,
  cp_dr_snapshot_update_time timestamp without time zone,
  cp_sp_profile_id bigint,
  cp_sp_json character varying(1024000), 
  cp_sp_snapshot_update_time timestamp without time zone,
  
  CONSTRAINT pk_cp_id PRIMARY KEY (cp_id),
  CONSTRAINT "fw_repo_FKey" FOREIGN KEY (cp_fw_repo_profile_id)
  		REFERENCES repository_profile_table (r_profile_id) MATCH SIMPLE
  		ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT "dr_repo_FKey" FOREIGN KEY (cp_dr_repo_profile_id)
  		REFERENCES repository_profile_table (r_profile_id) MATCH SIMPLE
  		ON UPDATE NO ACTION ON DELETE NO ACTION,
   
  CONSTRAINT cluster_profile_name_vmmAddress_UK1 UNIQUE (cp_name, cp_vmmserveraddress)
)
WITH (
  OIDS=FALSE
);

ALTER TABLE cluster_profile
  OWNER TO spectre_admin;
    

 CREATE SEQUENCE SEQ_CLUSTER_PROFILE
  MINVALUE 1000
  MAXVALUE 999999999999999999
  START WITH 1000
  NO CYCLE;
ALTER TABLE SEQ_CLUSTER_PROFILE OWNER TO spectre_admin;

CREATE TABLE cluster_profile_cluster_map
(
  cluster_profile_cluster_map_id bigint NOT NULL,
  cluster_id bigint,
  cluster_profile_id bigint,
   CONSTRAINT cluster_profile_cluster_map_pkey PRIMARY KEY (cluster_profile_cluster_map_id),
  CONSTRAINT fk_cluster_profile_cluster_map_cluster FOREIGN KEY (cluster_id)
      REFERENCES cluster_table (cluster_table_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_cluster_profile_cluster_map_cluster_profile FOREIGN KEY (cluster_profile_id)
      REFERENCES cluster_profile (cp_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITHOUT OIDS;
ALTER TABLE cluster_profile_cluster_map OWNER TO spectre_admin;

CREATE SEQUENCE SEQ_CLUSTER_PROFILE_CLUSTER_MAP
  MINVALUE 1000
  MAXVALUE 999999999999999999
  START WITH 1000
  NO CYCLE;
ALTER TABLE SEQ_CLUSTER_PROFILE_CLUSTER_MAP OWNER TO spectre_admin;



CREATE TABLE cluster_profile_host_map
(
  cluster_profile_host_map_id bigint NOT NULL,
  host_id bigint,
  cluster_profile_id bigint,
   CONSTRAINT cluster_profile_host_map_pkey PRIMARY KEY (cluster_profile_host_map_id),
  CONSTRAINT fk_cluster_profile_host_map_host FOREIGN KEY (host_id)
      REFERENCES host (host_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT fk_cluster_profile_host_map_cluster_profile FOREIGN KEY (cluster_profile_id)
      REFERENCES cluster_profile (cp_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION
)
WITHOUT OIDS;
ALTER TABLE cluster_profile_host_map OWNER TO spectre_admin;

CREATE SEQUENCE SEQ_CLUSTER_PROFILE_HOST_MAP
  MINVALUE 1000
  MAXVALUE 999999999999999999
  START WITH 1000
  NO CYCLE;
ALTER TABLE SEQ_CLUSTER_PROFILE_HOST_MAP OWNER TO spectre_admin;


-- Tables related to drift detection job
CREATE SEQUENCE SEQ_DRIFT_GRP
  MINVALUE 1000
  MAXVALUE 999999999999
  START WITH 1000
  NO CYCLE;
  ALTER TABLE SEQ_DRIFT_GRP OWNER TO spectre_admin;
  
CREATE SEQUENCE SEQ_DRIFT_DETAILS
  MINVALUE 1000
  MAXVALUE 999999999999
  START WITH 1000
  NO CYCLE;
  ALTER TABLE SEQ_DRIFT_DETAILS OWNER TO spectre_admin;    
  
CREATE TABLE drift_detection_group
(
  group_id bigint NOT NULL,
  job_name character varying(256),
  job_description character varying(2048),
  cp_id bigint NOT NULL,
  vmm_server_address character varying(255) NOT NULL DEFAULT 'UNKNOWN'::character varying,
  status character varying(255),
  user_name character varying(255),

  CONSTRAINT drift_detection_group_id_pkey PRIMARY KEY (group_id),
  CONSTRAINT drift_detection_group_name_key UNIQUE (job_name, vmm_server_address)
)
WITHOUT OIDS;
ALTER TABLE drift_detection_group OWNER TO spectre_admin;


CREATE TABLE drift_detection_group_details
(
  group_details_id bigint NOT NULL,
  group_id bigint NOT NULL,
  host_name character varying(256),
  status character varying(255),
  CONSTRAINT drift_detection_group_details_id_pkey PRIMARY KEY (group_details_id),
  CONSTRAINT "drift_detection_group_id_FK" FOREIGN KEY (group_id)
      REFERENCES drift_detection_group (group_id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE SET NULL
)
WITHOUT OIDS;
ALTER TABLE drift_detection_group_details OWNER TO spectre_admin;

CREATE TABLE baseline_compliance
(
  baseline_compliance_id bigint NOT NULL,
  host_id character varying(256) NOT NULL,
  host_name character varying(256),
  service_tag character varying(14),
  host_vmmserveraddress character varying(256),
  last_drift_checked_time timestamp without time zone,
  cp_id bigint NOT NULL,
  overall_compliance_status character varying(256),
  hardware_compliance_status character varying(256),
  firmware_compliance_status character varying(256),
  driver_compliance_status character varying(256),
  hardware_drift_json TEXT,
  firmware_drift_json TEXT,
  driver_drift_json TEXT,
   
  CONSTRAINT pk_bc_id PRIMARY KEY (baseline_compliance_id),
  CONSTRAINT "cp_bc_FKey" FOREIGN KEY (cp_id)
  		REFERENCES cluster_profile (cp_id) MATCH SIMPLE
  		ON UPDATE NO ACTION ON DELETE CASCADE
)
WITH (
  OIDS=FALSE
);

ALTER TABLE baseline_compliance
  OWNER TO spectre_admin;
    

 CREATE SEQUENCE SEQ_BASELINE_COMPLIANCE
  MINVALUE 1000
  MAXVALUE 999999999999999999
  START WITH 1000
  NO CYCLE;
ALTER TABLE SEQ_BASELINE_COMPLIANCE OWNER TO spectre_admin;

