DELETE FROM QRTZ_FIRED_TRIGGERS;
ALTER TABLE QRTZ_FIRED_TRIGGERS ADD COLUMN SCHED_TIME BIGINT NOT NULL;
ALTER TABLE HOST_COMPLIANCE ADD COLUMN IDRAC_VERSION character varying(25) NULL;
ALTER TABLE HOST_COMPLIANCE ADD COLUMN IDRAC_STATUS character varying(25) NULL;

ALTER TABLE deployable_server DROP COLUMN deployment_template_id;
ALTER TABLE deployable_server ADD COLUMN iso_profile_id bigint;
ALTER TABLE deployable_server ADD COLUMN system_profile_id bigint;
ALTER TABLE deployable_server ADD COLUMN local_appliance_network character varying(128) NULL;

ALTER TABLE deployable_group DROP COLUMN deployment_template_id;
ALTER TABLE deployable_group ADD COLUMN iso_profile_id bigint;
ALTER TABLE deployable_group ADD COLUMN system_profile_id bigint;

ALTER TABLE repository_profile_table ADD COLUMN r_global boolean DEFAULT FALSE;
ALTER TABLE repository_profile_table ADD COLUMN r_factory_created boolean DEFAULT FALSE;

ALTER TABLE system_profile ADD COLUMN sp_level INT DEFAULT 1000;

ALTER TABLE server_metrics ADD COLUMN overall_health character varying(255) NULL;
ALTER TABLE chassis_metrics ADD COLUMN overall_health character varying(255) NULL;
ALTER TABLE device_software ADD COLUMN description character varying(2048);

ALTER TABLE chassis ADD COLUMN last_inventory_status BOOLEAN DEFAULT FALSE;

--------------------------------------------------
-- Chassis firmware update table changes starts --
--------------------------------------------------
CREATE TABLE chassis_firmware_group
(
    group_id bigint NOT NULL,
    job_name character varying(256),
    job_description character varying(2048),
    vmm_server_address character varying(255) NOT NULL DEFAULT 'UNKNOWN'::character varying,
    status character varying(255),
    CONSTRAINT chassis_firmware_group_id_pkey PRIMARY KEY (group_id),
    CONSTRAINT chassis_firmware_group_name_key UNIQUE (job_name, vmm_server_address)
)
WITHOUT OIDS;
ALTER TABLE chassis_firmware_group OWNER TO spectre_admin;
 
CREATE TABLE chassis_firmware_group_details
(
    group_details_id bigint NOT NULL,
    group_id bigint NOT NULL,
    chassis_name character varying(256),
    service_tag character varying(256),
    model_name character varying(256), 
    component character varying(256),
    currentVersion character varying(256),
    availableVersion character varying(256),
    componentState character varying(256),
    description character varying(1024),
    rebootRequired character varying(256),
    sourceFilePath character varying(2048),
    sourcePassword character varying(2048),
    criticality character varying(4096),
    componentType character varying(256),
    componentId character varying(256),
    sourceUser character varying(256),
    releaseID character varying(256),
    status character varying(255),
    message_group character varying(256),
    CONSTRAINT chassis_firmware_group_details_id_pkey PRIMARY KEY (group_details_id),
    CONSTRAINT "group_id_FK" FOREIGN KEY (group_id) REFERENCES chassis_firmware_group (group_id) MATCH SIMPLE ON UPDATE NO ACTION ON DELETE SET NULL,
    CONSTRAINT chassis_unique_message_guid UNIQUE (message_group)
)
WITHOUT OIDS;
ALTER TABLE chassis_firmware_group_details OWNER TO spectre_admin;

CREATE TABLE chassis_firmware_details
(
	chassis_firmware_details_id bigint NOT NULL,
    chassis_id bigint NOT NULL,
    device_description  character varying(256),
    version character varying(256),
    InstanceId character varying(256),
    ComponentId character varying(256),
    CONSTRAINT chassis_firmware_details_pkey PRIMARY KEY (chassis_firmware_details_id),
    CONSTRAINT "chassis_firmware_details_FK" FOREIGN KEY (chassis_id)  REFERENCES chassis(chassis_id) ON UPDATE CASCADE ON DELETE CASCADE
)
WITHOUT OIDS;
ALTER TABLE chassis_firmware_details OWNER TO spectre_admin;

--------------------------------------------------
-- Chassis firmware update table changes ends --
--------------------------------------------------

--------------------------------------------------
-- Calendar table changes starts --
--------------------------------------------------
CREATE TABLE host_calendar_event
(
    event_id bigint NOT NULL,
    subject character varying(256),
    description character varying(2048),
    start_time timestamp without time zone,
    end_time timestamp without time zone,
    all_day boolean DEFAULT FALSE,
    private boolean DEFAULT FALSE,
    resource character varying(256),
    location character varying(255) NOT NULL DEFAULT 'UNKNOWN'::character varying
)
WITHOUT OIDS;
ALTER TABLE host_calendar_event OWNER TO spectre_admin;

CREATE SEQUENCE SEQ_CAL_EVENT
  MINVALUE 1000
  MAXVALUE 999999999999
  START WITH 1000
  NO CYCLE;
  ALTER TABLE SEQ_CAL_EVENT OWNER TO spectre_admin;
  
--------------------------------------------------
-- Calendar table changes ends --
--------------------------------------------------

