#!/bin/bash

GRUBCONF=/boot/grub2/grub.cfg
LOGFILE=/tmp/kernelCheck.log

now=`date`
echo "kernel check at $now" >> $LOGFILE
kernels=(`rpm -qa | grep ^kernel-[1-9] | sort -V | awk -F'-' '/^kernel-[1-9]/{printf "%s-%s\n",$2,$3}'`)

num=${#kernels[*]}
echo "$num kernel rpms found" >> $LOGFILE

if [ $num -eq 2 ]; then
    echo "Old kernel version is ${kernels[0]}" >> $LOGFILE
    echo "New kernel version is ${kernels[1]}" >> $LOGFILE
    echo "Update grub" >> $LOGFILE
    sed -i "/^default=1/d" $GRUBCONF
    sed -i "/CentOS/d" $GRUBCONF
    sed -i "/${kernels[1]}/d" $GRUBCONF
    sed -i "s~${kernels[0]}~${kernels[1]}~g" $GRUBCONF
    echo "Remove old kernel" >> $LOGFILE
    rpm -ev --nodeps kernel-${kernels[0]} &>> $LOGFILE
    rpm_retval=$?
    if [ $rpm_retval -ne 0 ]; then
        echo "Removing old kernel failed with errorcode: $rpm_retval"
        exit $rpm_retval
    fi
    now=`date`
    echo "Rebooting appliance at $now" >> $LOGFILE
    /sbin/reboot now >> $LOGFILE
else
    echo "Kernels:" >> $LOGFILE
    for kernel in ${kernels[@]} ; do
        echo $kernel >> $LOGFILE
    done
    running_kernel=`uname -r`
    echo "Loaded kernel: $running_kernel" >> $LOGFILE
    now=`date`
    echo "kernel sanitized at $now" >> $LOGFILE
fi
exit 0
