#!/bin/bash

THIS_DIR=$(cd $(dirname $0); pwd)

echo "********************Configuration Script Started*********************"

chkconfig spectreboot reset

echo "Setting Gnome workspace to just 1 for admin console"
gconftool-2 --direct --config-source xml:readwrite:/etc/gconf/gconf.xml.defaults --type int --set /apps/metacity/general/num_workspaces 1

# Apply the appliance secrets
sh /mnt/cv/app.sct/configure

# Update the dell_app_init.conf appliance console init_shell
sh $THIS_DIR/config_dell_app_init.sh

if [ -e /etc/ntp.conf ]; then 
    sed -i "s/server 0.centos.pool.ntp.org iburst//g;" /etc/ntp.conf
    sed -i "s/server 1.centos.pool.ntp.org iburst//g;" /etc/ntp.conf
    sed -i "s/server 2.centos.pool.ntp.org iburst//g;" /etc/ntp.conf
    sed -i "s/server 3.centos.pool.ntp.org iburst//g;" /etc/ntp.conf
fi

if [ -e /var/log/spectreboot ]; then 
    echo "------ Changing permissions for /var/log/spectreboot ----------"
	chmod 0644 /var/log/spectreboot
fi

if [ -e /tmp/cvinit.log ]; then 
    echo "------ Changing permissions for /tmp/cvinit.log ----------"
	chmod 0644 /tmp/cvinit.log
fi

if [ -e /var/www/html/misc ]; then 
    echo "------ Changing permissions for /var/www/html/misc ----------"
	chmod -R 0755 /var/www/html/misc
fi

if [ -e /var/www/html/SpectreLog ]; then 
    echo "------ Changing permissions for /var/www/html/misc ----------"
	chmod -R 0755 /var/www/html/SpectreLog
fi

if [ -e /var/log/messages ]; then 
    echo "------ Changing permissions for /var/log/messages ----------"
	chmod 0644 /var/log/messages
fi

echo "Setting up SELinux"
semodule -i $THIS_DIR/local.pp
semanage port -a -t http_port_t -p tcp 4433

# Running DB Script
#echo linux | passwd postgres --stdin
#su - postgres -c exit
if [ ! -e ${postgresql_path}/PG_VERSION ]; then 
       echo "------ PG_VERSION does not exist, run PostgreSQL initdb ----------"
       rm -rf /var/lib/pgsql/9.6/data/*
   	   #postgresql-setup initdb
   	   /usr/pgsql-9.6/bin/postgresql96-setup initdb
   	   systemctl enable ${postgresql}
fi
cp /usr/share/webapps/spectre/configscripts/pg_hba.conf.prd ${postgresql_path}/pg_hba.conf
cp /usr/share/webapps/spectre-vcenter/configscripts/postgresql.conf ${postgresql_path}
systemctl start ${postgresql}

sh /usr/share/webapps/spectre-vcenter/configscripts/VCenterDBScript.sh
sh /usr/share/webapps/spectre/configscripts/SpectreDBScript.sh

if [ "$?" -ne 0 ]
	then
		echo "Error executing DB Script."
fi

echo "Copying workers.properties into /etc/httpd/conf/"
cp $THIS_DIR/workers.properties /etc/httpd/conf/

echo "Copying httpd.conf into /etc/httpd/conf/"
cp -f $THIS_DIR/httpd.conf /etc/httpd/conf/
chmod 644 /etc/httpd/conf/httpd.conf

echo "Copying ssl.conf into /etc/httpd/conf.d"
cp -f $THIS_DIR/ssl.conf /etc/httpd/conf.d
chmod 644 /etc/httpd/conf.d/ssl.conf


echo "Copying spectre.conf into /etc/httpd/conf.d/"
cp $THIS_DIR/spectre.conf /etc/httpd/conf.d/

echo "Copying provision certificates to proper folder"
cp -r $THIS_DIR/certificates /etc/httpd/conf/ssl.crt
cp $THIS_DIR/ssl_provisionl.conf /etc/httpd/conf.d/

echo "Creating folders for customer certificates"
mkdir /usr/share/webapps/spectre/configscripts/customer/
chown tomcat.tomcat /usr/share/webapps/spectre/configscripts/customer/
mkdir /var/www/html/misc/
chown tomcat.tomcat /var/www/html/misc/
touch /tmp/certCheck.txt
chown tomcat.tomcat /tmp/certCheck.txt

#giving tomcat permission to replace license file
chown tomcat.tomcat /usr/share/webapps/spectre/Spectre/WEB-INF/classes/fileResource/LicenseConfig.xml.asc

echo "Establishing local PW file"
cp $THIS_DIR/passwords.spectre /etc/passwords.spectre
chown tomcat /etc/passwords.spectre
chgrp tomcat /etc/passwords.spectre
chmod 0640 /etc/passwords.spectre

echo "Patching SOAPPy"
SOAPPYPATH=/usr/lib/python2.7/site-packages/SOAPpy
cp $THIS_DIR/SOAPBuilder.py $SOAPPYPATH/SOAPBuilder.py
cp $THIS_DIR/SOAPClient.py $SOAPPYPATH/Client.py
rm $SOAPPYPATH/SOAPBuilder.pyc
rm $SOAPPYPATH/SOAPBuilder.pyo
rm $SOAPPYPATH/Client.pyc
rm $SOAPPYPATH/Client.pyo

echo "Workaround for NFS bug"
sed -i "s/udp6/#udp6/g;" /etc/netconfig
sed -i "s/tcp6/#tcp6/g;" /etc/netconfig

echo "Opening RPC ports needed for NFS"
# modify /etc/sysconfig/nfs to open the rpc ports for nfs
echo "STATD_PORT=4001" >> /etc/sysconfig/nfs
echo "LOCKD_TCPPORT=4002" >> /etc/sysconfig/nfs
echo "LOCKD_UDPPORT=4002" >> /etc/sysconfig/nfs
echo "MOUNTD_PORT=4003" >> /etc/sysconfig/nfs

echo "rquotad 4004/tcp" >> //etc/services
echo "rquotad 4004/udp" >> //etc/services

echo "setting up IPTABLES"
#lokkit -q --enabled -n
#lokkit -q -p 111:tcp -n
#lokkit -q -p 111:udp -n
#lokkit -q -p 80:tcp -n
#lokkit -q -p 443:tcp -n
#lokkit -q -p 4433:tcp -n
#lokkit -q -p 68:udp -n
#lokkit -q -p 69:udp -n
#lokkit -q -p 162:udp -n
#lokkit -q -p 11620:udp -n
#lokkit -q -p 2049:tcp -n
#lokkit -q -p 2049:udp -n
#lokkit -q -p 4001:udp -n
#lokkit -q -p 4001:tcp -n
#lokkit -q -p 4002:udp -n
#lokkit -q -p 4002:tcp -n
#lokkit -q -p 4003:udp -n
#lokkit -q -p 4003:tcp -n
#lokkit -q -p 4004:udp -n
#lokkit -q -p 4004:tcp -n
#chown root /etc/sysconfig/iptables
#chgrp root /etc/sysconfig/iptables
#This is for the trap listener redirection, do not run lokkit after this line, it will undo it
#cat $THIS_DIR/iptables_addition > /etc/sysconfig/iptables
#Since firewalld serve the purpose we dont need iptables. There is a risk in enabling both.
systemctl disable iptables

sh $THIS_DIR/fwdconfig.sh

systemctl restart  nfs.service

# security hardening - don't allow usage of pdb debugger from system-config-network-tui, which can exploited to get root access
sed -i --follow-symlinks  -e '/pdb/ s/.*/#commented out p d b/' /usr/bin/nmtui

echo "Secure and Disable ssh"
systemctl stop sshd
chkconfig sshd off
sshconf="/etc/ssh/sshd_config"
sshciphers=`grep -c '^Ciphers' ${sshconf}`
if [ ${sshciphers} -eq 0 ]; then
    echo "# restrict ciphers to reduce vulnerability" >> $sshconf
    echo "Ciphers aes128-ctr,aes192-ctr,aes256-ctr" >> $sshconf
fi

# Running SSL Configuration Script.
echo "Running SSL Configuration Script..."
sh $THIS_DIR/sslconfig.sh

if [ "$?" -ne 0 ]
	then
		echo "Error executing SSL Configuration Script (sslconfig.sh)."
		exit 1
	else
		echo "SSL Configured Successfully."
	
fi



systemctl restart httpd
#service tomcat5 restart

echo "Running nfssetup.sh..."
systemctl start rpcbind
sh $THIS_DIR/nfssetup.sh

echo "Setup autofs"
systemctl start autofs
chkconfig autofs on

echo "Configure yum"
rpm --import $THIS_DIR/Dell_VC_Plugin_Public.gpg
#rm $(ls /etc/yum.repos.d/* | grep -v spectre.repo)

echo "NTP ownership changes"
chown tomcat.tomcat /etc/ntp.conf
chown tomcat.tomcat /etc/ntp/step-tickers

echo "Turn on time sync from VMware Tools first."
#/usr/sbin/vmware-guestd --cmd "vmx.set_option synctime 0 1"

echo "Installing and Configuring VMwareTools"
#vmware-config-tools.pl --default
#/usr/share/webapps/spectre/vmwaretools/updateVMwareTools.sh firstRun >> /tmp/VMwareToolsLog

echo "Installing and Configuring VMware VCLI"
#vmware-vsphere-cli-distrib/vmware-install.pl --default
/usr/share/webapps/spectre/vmwaretools/updateVMwareVCLI.sh firstRun >> /tmp/VMwareVCLILog

echo "Disabling VMwareTools Balloon Driver"
locations=/etc/vmware-tools/locations
locations_tmp=/etc/vmware-tools/locations_tmp
#modprobe -r vmmemctl
sed "s-answer VMMEMCTL_CONFED yes-answer VMMEMCTL_CONFED no-" $locations > $locations_tmp ; mv $locations_tmp $locations

echo "Disabling martian logging"
sysctl_conf=/etc/sysctl.conf
sysctl_conf_temp=/tmp/sysctl.conf
sed "s-net.ipv4.conf.all.log_martians = 1-net.ipv4.conf.all.log_martians = 0-" $sysctl_conf > $sysctl_conf_temp ; mv $sysctl_conf_temp $sysctl_conf
sysctl net.ipv4.conf.all.log_martians=0

echo "Blacklisting acpiphp"
tmp_file=/tmp/modprobe.conf.tmp
sed 's_install pciehp /sbin/modprobe -q --ignore-install acpiphp; /bin/true_#install pciehp /sbin/modprobe -q --ignore-install acpiphp; /bin/true_' /etc/modprobe.d/appliance.conf > $tmp_file
#mv $tmp_file /etc/modprobe.conf
mv $tmp_file /etc/modprobe.d/appliance.conf
echo "blacklist acpiphp" >> /etc/modprobe.d/blacklist.conf
echo "blacklist acpiphp_ibm" >> /etc/modprobe.d/blacklist.conf

#for db backup/restore
sed 's/Defaults    requiretty/#Defaults    requiretty/' /etc/sudoers > /tmp/sudoers.bk
mv /tmp/sudoers.bk /etc/sudoers
chmod 0440 /etc/sudoers

echo "OpenManage Integration Virtual Appliance" > /etc/issue
echo "Log in as admin to continue" >> /etc/issue
echo  >> /etc/issue
sed 's_console__' /etc/securetty > /tmp/securetty ; mv /tmp/securetty /etc/securetty
sed 's_tty1__' /etc/securetty > /tmp/securetty ; mv /tmp/securetty /etc/securetty
sed 's_tty2__' /etc/securetty > /tmp/securetty ; mv /tmp/securetty /etc/securetty

echo "echo NOT SUPPORTED" > /root/.bash_profile
echo "export LANG=en_US.UTF-8" >> /root/.bash_profile
echo "export LANG=en_US.UTF-8" >> /home/admin/.bash_profile

#userdel -r abuild

echo "Setup log rotation"
mv /etc/cron.daily/logrotate /etc/cron.hourly/
cp $THIS_DIR/logrotate.d/httpd /etc/logrotate.d/
cp $THIS_DIR/logrotate.d/tomcatSpectre /etc/logrotate.d/

#workaround for system time in the future.
echo "********************Touch network files***********************"
#touch /etc/sysconfig/network-scripts/ifcfg-eth0
touch /etc/sysconfig/network
touch /etc/resolv.conf

#directory for spectre log zip
echo "********************Setup directory for SpectreLog***********************"
mkdir /var/www/html/SpectreLog/
chown tomcat.tomcat /var/www/html/SpectreLog/

#directory for kickstart files
echo "********************Setup directory for kickstart files***********************"
mkdir /var/www/html/ks/
chown tomcat.tomcat /var/www/html/ks/
chmod -R 0755 /var/www/html/ks/

#copy C lib 
#echo "********************copy C lib***********************"
#echo "cp -p /usr/share/webapps/spectre/configscripts/nativelib/libnativecommands.so /usr/lib/libnativecommands.so"
#cp -p /usr/share/webapps/spectre/configscripts/nativelib/libnativecommands.so /usr/lib/libnativecommands.so 
#chmod 755 /usr/lib/libnativecommands.so

#permissions for spectre.repo file
chown tomcat:tomcat /etc/yum.repos.d/spectre.repo

#creating symbolic link for configscripts for AR
ln -s /usr/share/webapps/spectre/configscripts/ /usr/share/tomcatSpectre/webapps/Spectre/

echo "********************Configuration Script Ended***********************"
		
