#!/bin/bash
THIS_DIR=$(cd $(dirname $0); pwd)

#Set the SSL conf file path
filepath="/etc/httpd/conf.d/ssl.conf"
path_ssl_temp="/etc/httpd/conf.d/ssl.conf.tmp"

#Set welcome screen conf path
welcomescreen="/etc/httpd/conf.d/welcome.conf"

#set Spectre tomcat server.xml path and temp file path
path_tomcat="/usr/share/tomcatSpectre/conf/server.xml"
path_tomcat_temp="/usr/share/tomcatSpectre/conf/server.xml.tmp"

#Check if the file is present or not?
#if [ ! -f $filepath ]; then
#	echo "Error: SSL configuration file not found!"
#	exit 1
#fi

# set up legacy md5 cryptography to enable authentication of legacy bare metal iDRACs
tls_legacy_settings="/etc/pki/tls/legacy-settings"
if [ ! -f $tls_legacy_settings ]; then
	echo "Turning on legacy encryption methods for backward compatibility of provisioning services"
	echo 'LegacySigningMDs MD5' >> $tls_legacy_settings
fi

#Disable log files
#sed 's/^ErrorLog/#ErrorLog/' $filepath > $path_ssl_temp
#mv $path_ssl_temp $filepath
#chmod 644 $filepath

#sed 's/^TransferLog/#TransferLog/' $filepath > $path_ssl_temp
#mv $path_ssl_temp $filepath
#chmod 644 $filepath

#sed 's/^LogLevel/#LogLevel/' $filepath > $path_ssl_temp
#mv $path_ssl_temp $filepath
#chmod 644 $filepath

#sed 's/^CustomLog/#CustomLog/' $filepath > $path_ssl_temp
#mv $path_ssl_temp $filepath
#chmod 644 $filepath

#********************** Fixing POODLE vulnerability, edit the SSLProtocol to disable sslv3  **********
#sed 's/^SSLProtocol all -SSLv2/SSLProtocol all -SSLv3 -SSLv2/' $filepath > $path_ssl_temp
#mv $path_ssl_temp $filepath
#chmod 644 $filepath

#honorcipher=`grep 'SSLHonorCipherOrder on' ${filepath}`
#if [ ${#honorcipher} -eq 0 ]; then
# 	echo "SSLHonorCipherOrder on" >> $filepath
#fi

#Start Conf
echo "**Start: Apache SSL and Tomcat Configuration**"

#Check if the <Virtual Host Tag is Present in the Conf file
#If the Virtual Host Tag is not present, fail and exit.
#vhosttag=`grep '<VirtualHost _default_:443>' ${filepath}`
#if [ ${#vhosttag} -eq 0 ]; then
# 	echo "SSL Configuration Failed: <VirualHost> tag not found in the ssl.conf file ... exiting script."
#  	exit 1
#fi

#Check if the configuration is already present or not?
#sslconfig=`grep '#Begin spectre_mod_ssl' ${filepath}` 

#If already present, then remove config.
#if [ ${#sslconfig} -gt 0 ]; then
#   perl -i -n -e "print if not /^#Begin spectre_mod_ssl/ ... /^#End spectre_mod_ssl/" ${filepath}
#fi

#Check if VirtualHost end tag is present or not?
#If not then fail and exit.
#vhosttag=`grep '</VirtualHost>' ${filepath}`
#if [ ${#vhosttag} -eq 0 ]; then
# 	echo "SSL Configuration Failed: </VirtualHost> tag not found in the ssl.conf file ... exiting script."
#  	exit 1
#fi

#Remove the </VirtualHost> tag to be added later
#perl -i -n -e "print if not /^<\/VirtualHost>/" ${filepath} 

#Begin the configuration region
#echo "#Begin spectre_mod_ssl" >> ${filepath}

#Add configuration steps.
#echo "#Send everything for context /VCenter/SpectreSecurity/DellAdminPortal to worker named worker1 (ajp13)" >> ${filepath}
#echo  "JkMount /VCenter/* worker1" >> ${filepath}
#echo  "JkMount /Spectre/* worker1" >> ${filepath}
#echo  "JkMount /SpectreSecurity/* worker1" >> ${filepath}
#echo  "JkMount /DellAdminPortal/* worker1" >> ${filepath}
#echo  "JkMount /SpectreManager/* worker1" >> ${filepath}

#End the configuration region.
#echo "#End spectre_mod_ssl" >> ${filepath}

#Add the </VirtualHost> closing tag.
#echo "</VirtualHost>" >> ${filepath}

#removing apache start screen
if [ -f $welcomescreen ]; then
	rm -f $welcomescreen
	if [ $? -ne 0 ]; then
		echo "Error removing welcome screen" >&2
	fi
fi

if [ ! -f $path_tomcat ]; then
	echo "Error! No server.xml found!"
	exit 1
fi

#disabling tomcat direct connection
sed '/<Connector port="8080"/,/\/>/d' $path_tomcat > $path_tomcat_temp ; mv $path_tomcat_temp $path_tomcat 

#Adding an address directive to/etc/tomcat/server.xml Connector tag

#Check if the address directive is already there
addressdirective=$(grep 'address="127.0.0.1"' $path_tomcat)

#If not present, then add.
if [ ${#addressdirective} -eq 0 ]; then
    sed s/disableUploadTimeout='"true"'/disableUploadTimeout='"true" address="127.0.0.1"'/ $path_tomcat > $path_tomcat_temp;mv $path_tomcat_temp $path_tomcat 
    sed s/port='"8009"'/port='"8009" address="127.0.0.1"'/ $path_tomcat > $path_tomcat_temp;mv $path_tomcat_temp $path_tomcat 
fi

if [ $? -ne 0 ]; then
	echo "Error disabling tomcat direct connection" >&2
	exit 1
fi

# disable default tomcat instance from starting on boot up
chkconfig tomcat off
if [ $? -ne 0 ]; then
	echo "Error configuring tomcat to be disabled on boot up" >&2
	exit 1
fi

#configuring tomcat-DMPVV and apache to run on boot up
chkconfig tomcatSpectre off
if [ $? -ne 0 ]; then
	echo "Error configuring tomcat-DMPVV to be disabled on boot up" >&2
	exit 1
fi

chkconfig httpd on
if [ $? -ne 0 ]; then
	echo "Error configuring apache to run on boot up" >&2
	exit 1
fi

#Adding the AdminPortal Security

#Adding the Default Spectre Admin User
mkdir -p /usr/share/apache/passwd
htpasswd -c -b /usr/share/apache/passwd/passwords.file admin systemlogin
echo "spectre-admin: admin" >> /usr/share/apache/passwd/groups.file
chown apache /usr/share/apache
chown apache /usr/share/apache/passwd
chown apache /usr/share/apache/passwd/passwords.file
chown apache /usr/share/apache/passwd/groups.file

#End Adding the Default Spectre Admin User

val=`/usr/share/webapps/spectre/configscripts/get_ip.sh`
/usr/share/webapps/spectre/configscripts/write_htaccess.sh ${val}

#End Adding the AdminPortal Security

#End Configuration.
echo "******Successfully Configured Apache SSL******"

if [ -d "$THIS_DIR/CA" ]; then

    echo "Setup/Update CA"

    rm -rf /root/CA
    mv $THIS_DIR/CA /root/
    cp /root/CA/openssl.cnf /usr/share/tomcatSpectre/spectressl
    chown tomcat:tomcat /usr/share/tomcatSpectre/spectressl
    chmod -R go-rwx /root/CA

    # Running Certificate Import Script.
    echo "Running Certificate Import Script..."
    sh $THIS_DIR/cert_import_script.sh

    echo "give tomcat permission to keystore"
    chown tomcat /usr/lib/jvm/java/jre/lib/security/cacerts

    echo "create keystore for wsman certs"
    cp -f /usr/lib/jvm/java/jre/lib/security/cacerts /usr/lib/jvm/java/jre/lib/security/wsmancerts
    chown tomcat /usr/lib/jvm/java/jre/lib/security/wsmancerts

fi
